@@ -162,6 +162,104 @@ class test_numexpr(TestCase):
                     [(b'mul_ddd', b'r0', b'r1[x]', b'r1[x]'),
                      (b'add_ddd', b'r0', b'r0', b'c2[2.0]')])
 
+    def test_str_contains_basic0(self):
+        res = evaluate('contains(b"abc", b"ab")')
+        assert_equal(res, True)
+
+    def test_str_contains_basic1(self):
+        haystack = array([b'abc', b'def', b'xyz', b'x11', b'za'])
+        res = evaluate('contains(haystack, b"ab")')
+        assert_equal(res, [True, False, False, False, False])
+
+    def test_str_contains_basic2(self):
+        haystack = array([b'abc', b'def', b'xyz', b'x11', b'za'])
+        res = evaluate('contains(b"abcd", haystack)')
+        assert_equal(res, [True, False, False, False, False])
+
+    def test_str_contains_basic3(self):
+        haystacks = array(
+            [b'abckkk', b'adef', b'xyz', b'x11abcp', b'za', b'abc'])
+        needles =   array(
+            [b'abc', b'def', b'aterr', b'oot', b'zu', b'ab' ])
+        res = evaluate('contains(haystacks, needles)')
+        assert_equal(res, [True, True, False, False, False, True])
+
+    def test_str_contains_basic4(self):
+        needles =  array(
+            [b'abc', b'def', b'aterr', b'oot', b'zu', b'ab c', b' abc',
+             b'abc '])
+        res = evaluate('contains(b"test abc here", needles)')
+        assert_equal(res, [True, False, False, False, False, False, True, True])
+
+    def test_str_contains_basic5(self):
+        needles =  array(
+            [b'abc', b'ab c', b' abc', b' abc ', b'\tabc', b'c h'])
+        res = evaluate('contains(b"test abc here", needles)')
+        assert_equal(res, [True, False, True, True, False, True])
+
+   # Compare operation of Python 'in' operator with 'contains' using a
+   # product of two lists of strings.
+    def test_str_contains_listproduct(self):
+        from itertools import product
+        small = [
+            'It w', 'as th', 'e Whit', 'e Rab', 'bit,', ' tro', 'tting',
+            ' sl', 'owly', ' back ', 'again,', ' and', ' lo', 'okin', 'g a',
+            'nxious', 'ly a', 'bou', 't a', 's it w', 'ent,', ' as i', 'f it',
+            ' had l', 'ost', ' some', 'thi', 'ng; a', 'nd ', 'she ', 'heard ',
+            'it mut', 'terin', 'g to ', 'its', 'elf ', "'The",
+            ' Duch', 'ess! T', 'he ', 'Duches', 's! Oh ', 'my dea', 'r paws',
+             '! Oh ', 'my f', 'ur ', 'and ', 'whiske', 'rs! ', 'She', "'ll g",
+            'et me', ' ex', 'ecu', 'ted, ', 'as su', 're a', 's f', 'errets',
+            ' are f', 'errets', '! Wh', 'ere ', 'CAN', ' I hav', 'e d',
+            'roppe', 'd t', 'hem,', ' I wo', 'nder?', "' A", 'lice',
+            ' gu', 'essed', ' in a', ' mom', 'ent ', 'tha', 't it w', 'as ',
+            'looki', 'ng f', 'or ', 'the fa', 'n and ', 'the', ' pai',
+            'r of w', 'hit', 'e kid', ' glo', 'ves', ', and ', 'she ',
+            'very g', 'ood', '-na', 'turedl', 'y be', 'gan h', 'unt', 'ing',
+            ' about', ' for t', 'hem', ', but', ' they ', 'wer', 'e nowh',
+            'ere to', ' be', ' se', 'en--', 'ever', 'ythin', 'g seem', 'ed ',
+            'to ', 'have c', 'hang', 'ed ', 'since', ' he', 'r swim', ' in',
+            ' the', ' pool,', ' and', ' the g', 'reat ', 'hal', 'l, w', 'ith',
+            ' th', 'e gl', 'ass t', 'abl', 'e and ', 'the', ' li', 'ttle',
+            ' doo', 'r, ha', 'd v', 'ani', 'shed c', 'omp', 'lete', 'ly.']
+        big = [
+            'It wa', 's the', ' W', 'hit', 'e ', 'Ra', 'bb', 'it, t', 'ro',
+            'tting s', 'lowly', ' back ', 'agai', 'n, and', ' l', 'ookin',
+            'g ', 'an', 'xiously', ' about ', 'as it w', 'ent, as', ' if ',
+            'it had', ' los', 't ', 'so', 'mething', '; and', ' she h',
+            'eard ', 'it ', 'mutteri', 'ng to', ' itself', " 'The ",
+            'Duchess', '! ', 'Th', 'e ', 'Duchess', '! Oh m', 'y de',
+            'ar paws', '! ', 'Oh my ', 'fu', 'r and w', 'hiskers', "! She'",
+            'll ', 'get', ' me ', 'execute', 'd,', ' a', 's ', 'su', 're as ',
+            'fe', 'rrets', ' are f', 'errets!', ' Wher', 'e CAN', ' I ha',
+            've dro', 'pped t', 'hem', ', I ', 'won', "der?' A",
+            'lice g', 'uess', 'ed ', 'in a m', 'omen', 't that', ' i',
+            't was l', 'ook', 'ing f', 'or th', 'e ', 'fan and', ' th', 'e p',
+            'air o', 'f whit', 'e ki', 'd glove', 's, and ', 'she v', 'ery ',
+            'good-na', 'tu', 'redl', 'y be', 'gan hun', 'ti', 'ng abou',
+            't for t', 'he', 'm, bu', 't t', 'hey ', 'were n', 'owhere',
+            ' to b', 'e s', 'een-', '-eve', 'rythi', 'ng see', 'me', 'd ',
+            'to ha', 've', ' c', 'hanged', ' sinc', 'e her s', 'wim ',
+            'in the ', 'pool,', ' an', 'd the g', 'rea', 't h', 'all, wi',
+            'th the ', 'glas', 's t', 'able an', 'd th', 'e littl', 'e door,',
+            ' had va', 'ni', 'shed co', 'mpletel', 'y.']
+        p = list(product(small, big))
+        python_in = [x[0] in x[1] for x in p]
+        a = [x[0].encode() for x in p]
+        b = [x[1].encode() for x in p]
+        res = [bool(x) for x in evaluate('contains(b, a)')]
+        assert_equal(res, python_in)
+
+    def test_str_contains_withemptystr1(self):
+        withemptystr = array([b'abc', b'def', b''])
+        res = evaluate('contains(b"abcd", withemptystr)')
+        assert_equal(res, [True, False, True])
+
+    def test_str_contains_withemptystr2(self):
+        withemptystr = array([b'abc', b'def', b''])
+        res = evaluate('contains(withemptystr, b"")')
+        assert_equal(res, [True, True, True])
+
 
 class test_numexpr2(test_numexpr):
     """Testing with 2 threads"""
@@ -204,15 +302,15 @@ class test_evaluate(TestCase):
         assert_array_equal(evaluate("x/2", truediv=False), x / 2)
         assert_array_equal(evaluate("x/2", truediv='auto'), x / 2)
         assert_array_equal(evaluate("x/2", truediv=True), x / 2.0)
-    
+
     def test_left_shift(self):
         x = arange(10, dtype='i4')
         assert_array_equal(evaluate("x<<2"), x << 2)
-    
+
     def test_right_shift(self):
         x = arange(10, dtype='i4')
         assert_array_equal(evaluate("x>>2"), x >> 2)
-    
+
     # PyTables uses __nonzero__ among ExpressionNode objects internally
     # so this should be commented out for the moment.  See #24.
     def test_boolean_operator(self):
